==> dnet-openaireplus-mapping-utils-2.0.5-20141113.142913-1-sources.jar: eu/dnetlib/actionmanager/actions/infopackage/DMFInfoPackageToHbaseXsltFunctions.java <==
package eu.dnetlib.actionmanager.actions.infopackage;

import org.w3c.dom.NodeList;

import eu.dnetlib.data.transform.xml.DmfToHbaseXsltFunctions;

public class DMFInfoPackageToHbaseXsltFunctions extends DmfToHbaseXsltFunctions {

	// dnet:oafInstanceFromMDStore($resultId, $hostedby, //dc:identifier, "userclaim:doi", "0.9")
	// public static String oafInstanceFromInfoPackage(
	// final String resultId,
	// final String hostedbyId,
	// final String hostedbyName,
	// final String provenance,
	// final String trust,
	// final NodeList nodelist) {
	// return oafInstanceFromDMF(resultId, hostedbyId, hostedbyName, provenance, trust, nodelist);
	// }

	// dnet:oafPersonFromInfoPackage($personId, ., "userclaim:doi", "0.9")
	public static String oafPersonFromInfoPackage(final String personId,
			final NodeList dataInfo,
			final String fullname,
			final String provenance,
			final String trust,
			final String collectedFromId,
			final String collectedFromName,
			final String originalId,
			final String dateOfCollection) {
		return oafPerson_FromDMF(personId, fullname, provenance, trust, dataInfo, collectedFromId, collectedFromName, originalId, dateOfCollection);
	}

	public static String oafResultFromInfoPackage(final String resultId,
			final NodeList dataInfo,
			final String provenance,
			final String trust,
			final String hostedbyId,
			final String hostedbyName,
			final String collectedFromId,
			final String collectedFromName,
			final String originalId,
			final String dateOfCollection,
			final NodeList nodelist) {
		return oafResult_FromDMF(resultId, provenance, trust, dataInfo, hostedbyId, hostedbyName, collectedFromId, collectedFromName, originalId,
				dateOfCollection, nodelist);
	}

	// dnet:oafPersonResultFromInfoPackage($resultId, $oafPerson, position(), "userclaim:doi", "0.9")
	public static String oafPersonResultFromInfoPackage(final String personId,
			final String resultId,
			final int rank,
			final String relClass,
			final String provenance,
			final String trust,
			final NodeList dataInfo) {
		return oafPersonResult_Authorship_FromDMF(personId, resultId, rank, relClass, provenance, trust, dataInfo);
	}

	// dnet:oafResultProjectFromInfoPackage($resultId, $projectId, "userclaim:doi", "0.9")
	public static String oafResultProjectFromInfoPackage(final String sourceId,
			final String targetId,
			final String relClass,
			final String provenance,
			final String trust,
			final NodeList dataInfo) {
		return oafResultProject_Outcome_FromDMF(sourceId, targetId, relClass, provenance, trust, dataInfo);
	}

}

==> dnet-openaireplus-mapping-utils-2.2.1-20150305.184931-1-sources.jar: eu/dnetlib/actionmanager/actions/infopackage/DMFInfoPackageToHbaseXsltFunctions.java <==
package eu.dnetlib.actionmanager.actions.infopackage;

import org.w3c.dom.NodeList;

import eu.dnetlib.data.transform.xml.DmfToHbaseXsltFunctions;

public class DMFInfoPackageToHbaseXsltFunctions extends DmfToHbaseXsltFunctions {

	// dnet:oafInstanceFromMDStore($resultId, $hostedby, //dc:identifier, "userclaim:doi", "0.9")
	// public static String oafInstanceFromInfoPackage(
	// final String resultId,
	// final String hostedbyId,
	// final String hostedbyName,
	// final String provenance,
	// final String trust,
	// final NodeList nodelist) {
	// return oafInstanceFromDMF(resultId, hostedbyId, hostedbyName, provenance, trust, nodelist);
	// }

	// dnet:oafPersonFromInfoPackage($personId, ., "userclaim:doi", "0.9")
	public static String oafPersonFromInfoPackage(final String personId,
			final NodeList dataInfo,
			final String fullname,
			final String provenance,
			final String trust,
			final String collectedFromId,
			final String collectedFromName,
			final String originalId,
			final String dateOfCollection) {
		return oafPerson_FromDMF(personId, fullname, provenance, trust, dataInfo, collectedFromId, collectedFromName, originalId, dateOfCollection);
	}

	public static String oafResultFromInfoPackage(final String resultId,
			final NodeList dataInfo,
			final String provenance,
			final String trust,
			final String hostedbyId,
			final String hostedbyName,
			final String collectedFromId,
			final String collectedFromName,
			final String originalId,
			final String dateOfCollection,
			final NodeList nodelist) {
		return oafResult_FromDMF(resultId, provenance, trust, dataInfo, hostedbyId, hostedbyName, collectedFromId, collectedFromName, originalId,
				dateOfCollection, nodelist);
	}

	// dnet:oafPersonResultFromInfoPackage($resultId, $oafPerson, position(), "userclaim:doi", "0.9")
	public static String oafPersonResultFromInfoPackage(final String personId,
			final String resultId,
			final int rank,
			final String relClass,
			final String provenance,
			final String trust,
			final NodeList dataInfo) {
		return oafPersonResult_Authorship_FromDMF(personId, resultId, rank, relClass, provenance, trust, dataInfo);
	}

	public static String oafResultProjectFromInfoPackage(final String sourceId,
			final String targetId,
			final String relClass,
			final String provenance,
			final String trust) {
		return oafResultProjectFromInfoPackage(sourceId, targetId, relClass, provenance, trust, null);
	}

	// dnet:oafResultProjectFromInfoPackage($resultId, $projectId, 'isProducedBy', $provenance, $trust)"
	public static String oafResultProjectFromInfoPackage(final String sourceId,
			final String targetId,
			final String relClass,
			final String provenance,
			final String trust,
			final NodeList dataInfo) {
		return oafResultProject_Outcome_FromDMF(sourceId, targetId, relClass, provenance, trust, dataInfo);
	}

}
